==> maven_3.5.4.orig.tar.xz: maven-maven-3.5.4/maven-settings-builder/src/main/java/org/apache/maven/settings/building/FileSettingsSource.java <==
package org.apache.maven.settings.building;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.File;

import org.apache.maven.building.FileSource;

/**
 * Wraps an ordinary {@link File} as a settings source.
 *
 * @author Benjamin Bentmann
 * 
 * @deprecated instead use {@link FileSource}
 */
@Deprecated
public class FileSettingsSource extends FileSource
    implements SettingsSource
{

    /**
     * Creates a new settings source backed by the specified file.
     *
     * @param settingsFile The settings file, must not be {@code null}.
     */
    public FileSettingsSource( File settingsFile )
    {
        super( settingsFile );
    }

    /**
     * Gets the settings file of this model source.
     *
     * @return The underlying settings file, never {@code null}.
     * @deprecated instead use {@link #getFile()}
     */
    @Deprecated
    public File getSettingsFile()
    {
        return getFile();
    }
}

==> maven_3.9.9.orig.tar.xz: maven-maven-3.9.9/maven-settings-builder/src/main/java/org/apache/maven/settings/building/FileSettingsSource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.settings.building;

import java.io.File;

import org.apache.maven.building.FileSource;

/**
 * Wraps an ordinary {@link File} as a settings source.
 *
 * @author Benjamin Bentmann
 *
 * @deprecated instead use {@link FileSource}
 */
@Deprecated
public class FileSettingsSource extends FileSource implements SettingsSource {

    /**
     * Creates a new settings source backed by the specified file.
     *
     * @param settingsFile The settings file, must not be {@code null}.
     */
    public FileSettingsSource(File settingsFile) {
        super(settingsFile);
    }

    /**
     * Gets the settings file of this model source.
     *
     * @return The underlying settings file, never {@code null}.
     * @deprecated instead use {@link #getFile()}
     */
    @Deprecated
    public File getSettingsFile() {
        return getFile();
    }
}
